@@ -5,14 +5,11 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <signal.h>
-#include <string.h>
 #include <time.h>
 #include <vga.h>
 #include <vgagl.h>
 #include <vgakeyboard.h>
 
-#define zero_sa_mask(maskptr) memset(maskptr, 0, sizeof(sigset_t))
-
 static char sig2release[] =
 {SIGHUP, SIGINT, SIGQUIT, SIGILL,
  SIGTRAP, SIGIOT, SIGBUS, SIGFPE,
@@ -42,7 +39,7 @@ void shutdown(void)
     puts("Shutdown called!");
 }
 
-int main(void)
+void main(void)
 {
     struct sigaction siga;
     int vgamode, color, leftpressed;
@@ -70,7 +67,7 @@ int main(void)
 
     /* Never do this in your code! */
     siga.sa_flags = 0;
-    zero_sa_mask(&(siga.sa_mask));
+    siga.sa_mask = 0;
     for (x = 0; x < sizeof(sig2release); x++) {
 	siga.sa_handler = SIG_DFL;
 	sigaction(sig2release[x], &siga, NULL);
