@@ -17,7 +17,8 @@
 #include "timing.h"
 #include "accel.h"
 
-#define MAX_REGS 269
+/* #define MAX_REGS 269 */
+#define MAX_REGS 385
 
 typedef struct {
 /* Basic functions. */
@@ -60,6 +61,8 @@ extern DriverSpecs et3000_driverspecs;
 extern DriverSpecs gvga6400_driverspecs;
 extern DriverSpecs ark_driverspecs;
 extern DriverSpecs ati_driverspecs;
+extern DriverSpecs ali_driverspecs;
+extern DriverSpecs mach64_driverspecs;
 
 extern DriverSpecs *driverspecs;
 extern DriverSpecs *driverspecslist[];
