@@ -123,7 +123,7 @@ static int sr_accel[13] =
  ioMEM_VGA_WP_SEL};
 
 /* Driverspecs function table (exported) */
-DriverSpecs __svgalib_mach64_driverspecs =
+DriverSpecs mach64_driverspecs =
 {
     mach64_saveregs,
     mach64_setregs,
@@ -131,9 +131,9 @@ DriverSpecs __svgalib_mach64_driverspecs =
     (void (*)(void)) nothing,	/* lock */
     mach64_test,
     mach64_init,
-    mach64_setpage,		/* __svgalib_setpage */
-    (void (*)(int)) nothing,	/* __svgalib_setrdpage */
-    (void (*)(int)) nothing,	/* __svgalib_setwrpage */
+    mach64_setpage,		/* setpage */
+    (void (*)(int)) nothing,	/* setrdpage */
+    (void (*)(int)) nothing,	/* setwrpage */
     mach64_setmode,
     mach64_modeavailable,
     mach64_setdisplaystart,
@@ -165,7 +165,7 @@ static int mach64_init(int force, int par1, int par2)
     if (__svgalib_driver_report)
 	fprintf(stdout, "Using ATI Mach64 driver.\n");
 
-    __svgalib_driverspecs = &__svgalib_mach64_driverspecs;
+    driverspecs = &mach64_driverspecs;
 
     /* Make sure we are operating at IO priveleges are level 3 */
     if (iopl(3) < 0) {
@@ -926,7 +926,7 @@ static void mach64_setregs(const UB * regs, int mode)
 
 static void mach64_getmodeinfo(int mode, vga_modeinfo * modeinfo)
 {
-    /*__svgalib_vga_driverspecs.getmodeinfo(mode, modeinfo); */
+    /*vga_driverspecs.getmodeinfo(mode, modeinfo); */
     modeinfo->startaddressrange = 0xfffff;
 /*      modeinfo->startaddressrange=0xfffffffc&(2048*1024-1);
  */
@@ -948,7 +948,7 @@ static int mach64_modeavailable(int mode)
     if (mode > __GLASTMODE)
 	return 0;
     if (mode < G640x480x256 || mode == G720x348x2)
-	return __svgalib_vga_driverspecs.modeavailable(mode);
+	return vga_driverspecs.modeavailable(mode);
     else if (mode != G640x480x256)
 	return 0;
 
@@ -963,7 +963,7 @@ static int mach64_setmode(int mode, int prv_mode)
     mach64_setregs(regs, mode);
 
     if (mode < G640x480x256 || mode == G720x348x2)
-	return __svgalib_vga_driverspecs.setmode(mode, prv_mode);
+	return vga_driverspecs.setmode(mode, prv_mode);
 
     if (mode == G640x480x256) {
 
@@ -1034,12 +1034,12 @@ static int mach64_setmode(int mode, int prv_mode)
 
 static void mach64_setdisplaystart(int address)
 {
-    /*__svgalib_vga_driverspecs.setdisplaystart(address); */
+    /*vga_driverspecs.setdisplaystart(address); */
 }
 
 static void mach64_setlogicalwidth(int width)
 {
-    /*__svgalib_vga_driverspecs.setlogicalwidth(width); */
+    /*vga_driverspecs.setlogicalwidth(width); */
 }
 
 static void mach64_setpage(int page)
