@@ -37,7 +37,6 @@
    the documentation, a 2 meg board should be able to do an interlaced
    1280x1024x256.  I couldn't force Oak's BIOS to enter that mode.
    Could be because I have only 1 meg on board.
-
  */
 
 #include <stdio.h>
@@ -140,6 +139,11 @@ static ModeTable oak_modes[] =
 
 
 
+
+
+
+
+
 };
 
 /* oak_getmodeinfo( int mode, vga_modeinfo *modeinfo)   Tell SVGALIB stuff
@@ -345,7 +349,13 @@ static int oak_setmode(int mode, int prv_mode)
 	} else {
 	    regs[OTI_CONFIG_DATA] &= 0xF7;
 	}
+    } else {			/* oak_chiptype == 87 */
+	if (mode == G640x480x256) {
+	    /* Oak-87 needs this bit, Oak-67 does not stand it - MW */
+	    regs[SEQ + 1] |= 0x8;
+	}
     }
+
     if (__svgalib_infotable[mode].colors == 16) {
 
 	/* switch from 256 to 16 color mode (from XFree86) */
