@@ -34,7 +34,7 @@ static void Sierra_32K_init(void)
 {
     /* Should probe the exact DAC type. */
     if (__svgalib_driver_report)
-	fprintf(stderr,"svgalib: Using Sierra 32K DAC.\n");
+	printf("svgalib: Using Sierra 32K DAC.\n");
 }
 
 static int Sierra_32K_map_clock(int bpp, int pixelclock)
@@ -54,16 +54,16 @@ static int Sierra_32K_map_horizontal_crtc(int bpp, int pixelclock, int htiming)
 
 #if defined(INCLUDE_SIERRA_DAC) || defined(INCLUDE_ICW_DAC) || \
     defined(INCLUDE_ATT20C490_DAC) || defined(INCLUDE_ATT20C498_DAC)
-void __svgalib_Sierra_32K_savestate(unsigned char *regs)
+void Sierra_32K_savestate(unsigned char *regs)
 {
     _ramdac_dactocomm();
-    regs[0] = port_in(PEL_MSK);
+    regs[0] = inb(PEL_MSK);
 }
 
-void __svgalib_Sierra_32K_restorestate(const unsigned char *regs)
+void Sierra_32K_restorestate(const unsigned char *regs)
 {
     _ramdac_dactocomm();
-    port_out_r(PEL_MSK, regs[0]);
+    outb(PEL_MSK, regs[0]);
 }
 
 #endif
@@ -79,7 +79,7 @@ static void Sierra_32K_initializestate(unsigned char *regs, int bpp, int colormo
 
 static void Sierra_32K_qualify_cardspecs(CardSpecs * cardspecs, int dacspeed)
 {
-    dacspeed = __svgalib_setDacSpeed(dacspeed, 80000);
+    dacspeed = _setDacSpeed(dacspeed, 80000);
     cardspecs->maxPixelClock4bpp = dacspeed;
     cardspecs->maxPixelClock8bpp = dacspeed;
     cardspecs->maxPixelClock16bpp = dacspeed / 2;
@@ -90,7 +90,7 @@ static void Sierra_32K_qualify_cardspecs(CardSpecs * cardspecs, int dacspeed)
     cardspecs->flags |= NO_RGB16_565;
 }
 
-DacMethods __svgalib_Sierra_32K_methods =
+DacMethods Sierra_32K_methods =
 {
     SIERRA_32K,
     "Sierra 32K colors VGA DAC",
@@ -98,8 +98,8 @@ DacMethods __svgalib_Sierra_32K_methods =
     Sierra_32K_probe,
     Sierra_32K_init,
     Sierra_32K_qualify_cardspecs,
-    __svgalib_Sierra_32K_savestate,
-    __svgalib_Sierra_32K_restorestate,
+    Sierra_32K_savestate,
+    Sierra_32K_restorestate,
     Sierra_32K_initializestate,
     1				/* State size. */
 };
@@ -119,11 +119,11 @@ static int SC15025_probe(void)
     int i, flag = 0;
 
     _ramdac_dactocomm();
-    c = port_in(PEL_MSK);
+    c = inb(PEL_MSK);
     _ramdac_setcomm(c | 0x10);
     for (i = 0; i < 4; i++) {
-	port_out_r(PEL_IR, 0x9 + i);
-	id[i] = port_in(PEL_IW);
+	outb(PEL_IR, 0x9 + i);
+	id[i] = inb(PEL_IW);
     }
     _ramdac_setcomm(c);
     _ramdac_dactopel();
@@ -143,7 +143,7 @@ static int SC15025_probe(void)
 static void SC15025_init(void)
 {
     if (__svgalib_driver_report)
-	fprintf(stderr,"svgalib: Using Sierra 15025/26%c truecolor DAC.\n", SC15025_Rev);
+	printf("svgalib: Using Sierra 15025/26%c truecolor DAC.\n", SC15025_Rev);
 }
 
 static void SC15025_initializestate(unsigned char *regs, int bpp, int colormode,
@@ -170,13 +170,13 @@ static void SC15025_initializestate(unsigned char *regs, int bpp, int colormode,
 static void SC15025_savestate(unsigned char *regs)
 {
     _ramdac_dactocomm();
-    regs[0] = port_in(PEL_MSK);
+    regs[0] = inb(PEL_MSK);
     _ramdac_setcomm(regs[0] | 0x10);
     _ramdac_dactocomm();
-    port_out_r(PEL_IR, 8);
-    regs[1] = port_in(PEL_IW);	/* Aux control */
-    port_out_r(PEL_IR, 16);
-    regs[2] = port_in(PEL_IW);	/* Pixel Repack */
+    outb(PEL_IR, 8);
+    regs[1] = inb(PEL_IW);	/* Aux control */
+    outb(PEL_IR, 16);
+    regs[2] = inb(PEL_IW);	/* Pixel Repack */
     _ramdac_setcomm(regs[0]);
 }
 
@@ -185,13 +185,13 @@ static void SC15025_restorestate(const unsigned char *regs)
     unsigned char c;
 
     _ramdac_dactocomm();
-    c = port_in(PEL_MSK);
+    c = inb(PEL_MSK);
     _ramdac_setcomm(c | 0x10);
     _ramdac_dactocomm();
-    port_out_r(PEL_IR, 8);
-    port_out_r(PEL_IW, regs[1]);	/* Aux control */
-    port_out_r(PEL_IR, 16);
-    port_out_r(PEL_IW, regs[2]);	/* Pixel Repack */
+    outb(PEL_IR, 8);
+    outb(PEL_IW, regs[1]);	/* Aux control */
+    outb(PEL_IR, 16);
+    outb(PEL_IW, regs[2]);	/* Pixel Repack */
     _ramdac_setcomm(c);
     _ramdac_setcomm(regs[0]);
 }
@@ -214,7 +214,7 @@ static int SC15025_map_horizontal_crtc(int bpp, int pixelclock, int htiming)
 
 static void SC15025_qualify_cardspecs(CardSpecs * cardspecs, int dacspeed)
 {
-    dacspeed = __svgalib_setDacSpeed(dacspeed, 110000);
+    dacspeed = _setDacSpeed(dacspeed, 110000);
     cardspecs->maxPixelClock4bpp = dacspeed;
     cardspecs->maxPixelClock8bpp = dacspeed;
     cardspecs->maxPixelClock16bpp = dacspeed / 2;
@@ -224,7 +224,7 @@ static void SC15025_qualify_cardspecs(CardSpecs * cardspecs, int dacspeed)
     cardspecs->mapHorizontalCrtc = SC15025_map_horizontal_crtc;
 }
 
-DacMethods __svgalib_SC15025_methods =
+DacMethods SC15025_methods =
 {
     SIERRA_15025,
     "Sierra SC15025/6 DAC",
@@ -265,32 +265,32 @@ static int SC1148X_probe(void)
     int flag = 0;
 
     _ramdac_dactopel();
-    tmp = port_in(PEL_MSK);
+    tmp = inb(PEL_MSK);
     do {
 	tmp2 = tmp;
-	tmp = port_in(PEL_MSK);
+	tmp = inb(PEL_MSK);
     } while (tmp2 != tmp);
-    port_in(PEL_IW);
-    port_in(PEL_MSK);
-    port_in(PEL_MSK);
-    port_in(PEL_MSK);
+    inb(PEL_IW);
+    inb(PEL_MSK);
+    inb(PEL_MSK);
+    inb(PEL_MSK);
     for (tmp2 = 9; tmp != 0x8E && tmp2 > 0; tmp2--)
-	tmp = port_in(PEL_MSK);
+	tmp = inb(PEL_MSK);
     if (tmp != 0x8E) {
         _ramdac_dactocomm();
-        oc = port_in(PEL_MSK);
+        oc = inb(PEL_MSK);
         _ramdac_dactopel();
-        op = port_in(PEL_MSK);
+        op = inb(PEL_MSK);
         tmp = oc ^ 0xFF;
-        port_out_r(PEL_MSK, tmp);
+        outb(PEL_MSK, tmp);
         _ramdac_dactocomm();
-        tmp2 = port_in(PEL_MSK);
+        tmp2 = inb(PEL_MSK);
         if (tmp2 != tmp) {
             tmp = _ramdac_setcomm(tmp = oc ^ 0x60);
             if ((tmp & 0xe0) == (tmp2 & 0xe0)) {
-                tmp = port_in(PEL_MSK);
+                tmp = inb(PEL_MSK);
                 _ramdac_dactopel();
-                if (tmp != port_in(PEL_MSK))
+                if (tmp != inb(PEL_MSK))
 		    flag = 1; /* Sierra Mark 2 or 3 */
 	    } else {
 		/* We have a Sierra SC11486 */
@@ -299,18 +299,18 @@ static int SC1148X_probe(void)
 		/* We do some ugly trickery here to patch SC1148X Series
 		    descriptor with values from Sierra 32K descriptor, since
 		    this is what whe really have detected! */
-		__svgalib_SC1148X_methods.id = SIERRA_32K;
-		__svgalib_SC1148X_methods.name = __svgalib_Sierra_32K_methods.name;
-		__svgalib_SC1148X_methods.initialize = __svgalib_Sierra_32K_methods.initialize;
-		__svgalib_SC1148X_methods.qualifyCardSpecs = __svgalib_Sierra_32K_methods.qualifyCardSpecs ;
-		__svgalib_SC1148X_methods.initializeState = __svgalib_Sierra_32K_methods.initializeState ;
+		SC1148X_methods.id = SIERRA_32K;
+		SC1148X_methods.name = Sierra_32K_methods.name;
+		SC1148X_methods.initialize = Sierra_32K_methods.initialize;
+		SC1148X_methods.qualifyCardSpecs = Sierra_32K_methods.qualifyCardSpecs ;
+		SC1148X_methods.initializeState = Sierra_32K_methods.initializeState ;
 #endif
 	    }
 	    _ramdac_dactocomm();
-	    port_out_r(PEL_MSK, oc);
+	    outb(PEL_MSK, oc);
 	}
 	_ramdac_dactopel();
-	port_out_r(PEL_MSK, op);
+	outb(PEL_MSK, op);
     } else {
 	_ramdac_dactopel();
 	/* Diamond SS2410 */
@@ -325,7 +325,7 @@ static int SC1148X_probe(void)
 static void SC1148X_init(void)
 {
     if (__svgalib_driver_report)
-	fprintf(stderr,"svgalib: Using Sierra 1148x series 32K DAC.\n");
+	printf("svgalib: Using Sierra 1148x series 32K DAC.\n");
 }
 
 static void SC1148X_initializestate(unsigned char *regs, int bpp, int colormode,
@@ -341,7 +341,7 @@ static void SC1148X_initializestate(unsigned char *regs, int bpp, int colormode,
 
 static void SC1148X_qualify_cardspecs(CardSpecs * cardspecs, int dacspeed)
 {
-    dacspeed = __svgalib_setDacSpeed(dacspeed, 110000);
+    dacspeed = _setDacSpeed(dacspeed, 110000);
     cardspecs->maxPixelClock4bpp = dacspeed;
     cardspecs->maxPixelClock8bpp = dacspeed;
     cardspecs->maxPixelClock16bpp = dacspeed / 2;
@@ -352,7 +352,7 @@ static void SC1148X_qualify_cardspecs(CardSpecs * cardspecs, int dacspeed)
     cardspecs->flags |= NO_RGB16_565;	/* Mark 3 (11485,87, and higher) can */
 }
 
-DacMethods __svgalib_SC1148X_methods =
+DacMethods SC1148X_methods =
 {
     SIERRA_1148X,
     "Sierra SC1148x series 32K colors VGA DAC",
@@ -360,8 +360,8 @@ DacMethods __svgalib_SC1148X_methods =
     SC1148X_probe,
     SC1148X_init,
     SC1148X_qualify_cardspecs,
-    __svgalib_Sierra_32K_savestate,
-    __svgalib_Sierra_32K_restorestate,
+    Sierra_32K_savestate,
+    Sierra_32K_restorestate,
     SC1148X_initializestate,
     1				/* State size. */
 };
