@@ -34,7 +34,6 @@
 #include "mouse/vgamouse.h"
 #include "keyboard/vgakeyboard.h"
 
-
 /* Delay in microseconds after a mode is set (screen is blanked during this */
 /* time), allows video signals to stabilize */
 #define MODESWITCHDELAY 150000
@@ -111,6 +110,20 @@ struct info infotable[] =
     {1024, 768, 1 << 24, 1024 * 4, 4},
     {1280, 1024, 1 << 24, 1280 * 4, 4},
 
+    {1152, 864, 16, 144, 0},
+    {1152, 864, 256, 1152, 1},
+    {1152, 864, 1 << 15, 1152 * 2, 2},
+    {1152, 864, 1 << 16, 1152 * 2, 2},
+    {1152, 864, 1 << 24, 1152 * 3, 3},
+    {1152, 864, 1 << 24, 1152 * 4, 4},
+
+    {1600, 1200, 16, 200, 0},
+    {1600, 1200, 256, 1600, 1},
+    {1600, 1200, 1 << 15, 1600 * 2, 2},
+    {1600, 1200, 1 << 16, 1600 * 2, 2},
+    {1600, 1200, 1 << 24, 1600 * 3, 3},
+    {1600, 1200, 1 << 24, 1600 * 4, 4},
+
     {0, 0, 0, 0, 0},		/* 16 user definable modes */
     {0, 0, 0, 0, 0},
     {0, 0, 0, 0, 0},
@@ -239,6 +252,7 @@ static unsigned __svgalib_maxhsync[] =
 static int lastmodenumber = __GLASTMODE;	/* Last defined mode */
 static int my_pid = 0;		/* process PID, used with atexit() */
 static int currentpage;
+static int vga_page_offset;	/* offset to add to all vga_set*page() calls */
 static int currentlogicalwidth;
 static int currentdisplaystart;
 static int mouse_support = 0;
@@ -346,11 +360,21 @@ DriverSpecs *driverspecslist[] =
 #else
     NULL,
 #endif
+#ifdef INCLUDE_ALI_DRIVER
+    &ali_driverspecs,
+#else
+    NULL,
+#endif
+#ifdef INCLUDE_MACH64_DRIVER
+    &mach64_driverspecs,
+#else
+    NULL
+#endif
 };
 
 static char *driver_names[] =
 {"", "VGA", "ET4000", "Cirrus", "TVGA", "Oak", "EGA", "S3",
- "ET3000", "Mach32", "GVGA6400", "ARK", "ATI", NULL};
+ "ET3000", "Mach32", "GVGA6400", "ARK", "ATI", "ALI", "Mach64", NULL};
 
 /* Chipset drivers */
 
@@ -365,9 +389,13 @@ static char *driver_names[] =
 /* ark          ARK Logic */
 /* gvga6400     Genoa 6400 (old SVGA) */
 /* ati          ATI */
+/* ali          ALI2301 */
+/* mach64	ATI MACH64 */
 
 /*#define DEBUG */
-																																																															  /*#define DEBUG_CONF *//*Debug config file parsing.. */
+
+/* Debug config file parsing.. */
+/*#define DEBUG_CONF */
 
 #ifdef DEBUG
 static void _DEBUG(int dnr)
@@ -451,7 +479,8 @@ void __svgalib_waitvtactive(void)
     close(fd);
 
     fd = dup(2);
-    ioctl(fd, VT_WAITACTIVE, minor);
+    while (ioctl(fd, VT_WAITACTIVE, minor) < 0)
+	sleep(1);
     close(fd);
 }
 
@@ -588,6 +617,35 @@ void __vga_delay(void)
 }
 
 /* The Xfree server uses a slow copy, may help us too ... */
+#if defined(CONFIG_ALPHA_JENSEN)
+extern unsigned long vga_readl(unsigned long base, unsigned long off);
+extern void vga_writel(unsigned long b, unsigned long base, unsigned long off);
+static void slowcpy_from_sm(unsigned char *dest, unsigned char *src, unsigned bytes)
+{
+    long i;
+    if (((long) dest & 7) || ((long) src & 7) || bytes & 7) {
+	printf("svgalib: unaligned slowcpy()!\n");
+	exit(-1);
+    }
+    for (i = 0; i < bytes; i++) {
+	*(dest + i) = (*(unsigned long *) (src + (i << 7)) >> ((i & 0x03) * 8))
+	    & 0xffUL;
+    }
+}
+static void slowcpy_to_sm(unsigned char *dest, unsigned char *src, unsigned bytes)
+{
+    long i;
+    if (((long) dest & 7) || ((long) src & 7) || bytes & 7) {
+	printf("svgalib: unaligned slowcpy()!\n");
+	exit(-1);
+    }
+    for (i = 0; i < bytes; i++) {
+	*(unsigned long *) (dest + (i << 7)) =
+	    (*(unsigned char *) (src + i)) * 0x01010101UL;
+    }
+}
+
+#else
 static void slowcpy(unsigned char *dest, unsigned char *src, unsigned bytes)
 {
 #ifdef __alpha__
@@ -606,6 +664,7 @@ static void slowcpy(unsigned char *dest, unsigned char *src, unsigned bytes)
 	*(dest++) = *(src++);
 #endif
 }
+#endif
 
 int __vga_saveregs(unsigned char *regs)
 {
@@ -760,6 +819,11 @@ int __vga_getchipset(void)
     __vga_get_perm();
     if (CHIPSET == UNDEFINED) {
 	CHIPSET = VGA;		/* Protect against recursion */
+#ifdef INCLUDE_MACH64_DRIVER_TEST
+	if (mach64_driverspecs.test())
+	    CHIPSET = MACH64;
+	else
+#endif
 #ifdef INCLUDE_MACH32_DRIVER_TEST
 	if (mach32_driverspecs.test())
 	    CHIPSET = MACH32;
@@ -816,6 +880,11 @@ int __vga_getchipset(void)
 	    CHIPSET = ATI;
 	else
 #endif
+#ifdef INCLUDE_ALI_DRIVER_TEST
+	if (ali_driverspecs.test())
+	    CHIPSET = ALI;
+	else
+#endif
 
 	if (vga_driverspecs.test())
 	    CHIPSET = VGA;
@@ -1064,7 +1133,7 @@ static void __vga_mmap(void)
 #ifdef __alpha__
     SM = (unsigned char *) mmap(
 				   (caddr_t) 0,
-				   GRAPH_SIZE << 5,
+				   GRAPH_SIZE << MEM_SHIFT,
 				   PROT_READ | PROT_WRITE,
 				   MAP_SHARED,
 				   __svgalib_mem_fd,
@@ -1217,13 +1286,24 @@ static void initialize(void)
     /* save font data in plane 2 */
     port_out(0x04, GRA_I);
     port_out(0x02, GRA_D);
+#ifdef __alpha__
+    port_out(0x06, GRA_I);
+    port_out(0x00, GRA_D);
+#endif
+#if defined(CONFIG_ALPHA_JENSEN)
+    slowcpy_from_sm(font_buf1, SM, FONT_SIZE);
+#else
     slowcpy(font_buf1, GM, FONT_SIZE);
+#endif
 
     /* save font data in plane 3 */
     port_out(0x04, GRA_I);
     port_out(0x03, GRA_D);
+#if defined(CONFIG_ALPHA_JENSEN)
+    slowcpy_from_sm(font_buf2, SM, FONT_SIZE);
+#else
     slowcpy(font_buf2, GM, FONT_SIZE);
-
+#endif
     initialized = 1;
 
     /* do our own interrupt handling */
@@ -1242,27 +1322,30 @@ static void initialize(void)
 
 inline void vga_setpage(int p)
 {
+    p += vga_page_offset;
     if (p == currentpage)
 	return;
-    setpage(p);
+    (*setpage) (p);
     currentpage = p;
 }
 
 
 void vga_setreadpage(int p)
 {
+    p += vga_page_offset;
     if (p == currentpage)
 	return;
-    setrdpage(p);
+    (*setrdpage) (p);
     currentpage = -1;
 }
 
 
 void vga_setwritepage(int p)
 {
+    p += vga_page_offset;
     if (p == currentpage)
 	return;
-    setwrpage(p);
+    (*setwrpage) (p);
     currentpage = -1;
 }
 
@@ -1432,12 +1515,24 @@ int vga_setmode(int mode)
 	/* restore font data in plane 2 - necessary for all VGA's */
 	port_out(0x02, SEQ_I);
 	port_out(0x04, SEQ_D);
+#ifdef __alpha__
+	port_out(0x06, GRA_I);
+	port_out(0x00, GRA_D);
+#endif
+#if defined(CONFIG_ALPHA_JENSEN)
+	slowcpy_to_sm(SM, font_buf1, FONT_SIZE);
+#else
 	slowcpy(GM, font_buf1, FONT_SIZE);
+#endif
 
 	/* restore font data in plane 3 - necessary for Trident VGA's */
 	port_out(0x02, SEQ_I);
 	port_out(0x08, SEQ_D);
+#if defined(CONFIG_ALPHA_JENSEN)
+	slowcpy_to_sm(SM, font_buf2, FONT_SIZE);
+#else
 	slowcpy(GM, font_buf2, FONT_SIZE);
+#endif
 
 	fontloadingcomplete();
 
@@ -2158,30 +2253,37 @@ void vga_blitwait(void)
 int vga_ext_set(unsigned what,...)
 {
     va_list params;
-    register int retval;
+    register int retval = 0;
 
-    /* Does this use of the arglist corrupt non-AVAIL_ACCEL ext_set? */
-    va_start(params, what);
-    if (what == VGA_EXT_AVAILABLE
-	&& va_arg(params, int) == VGA_AVAIL_ACCEL) {
-	if (driverspecs->accelspecs == NULL)
-	    return 0;
-	else
-	    return driverspecs->accelspecs->operations;
-    }
-    va_end(params);
-
-    if (MODEFLAGS & HAVE_EXT_SET) {
+    if (what == VGA_EXT_AVAILABLE) {
+	/* Does this use of the arglist corrupt non-AVAIL_ACCEL ext_set? */
 	va_start(params, what);
-	retval = driverspecs->ext_set(what, params);
+	switch (va_arg(params, int)) {
+	case VGA_AVAIL_ACCEL:
+	    if (driverspecs->accelspecs == NULL)
+		return 0;
+	    else
+		return driverspecs->accelspecs->operations;
+	case VGA_AVAIL_SET:
+	    retval = 1 << VGA_EXT_PAGE_OFFSET;	/* This is handled by us */
+	}
+	va_end(params);
+    } else if (what == VGA_EXT_PAGE_OFFSET) {
+	/* Does this use of the arglist corrupt it? */
+	va_start(params, what);
+	retval = vga_page_offset;
+	vga_page_offset = va_arg(params, int);
 	va_end(params);
 	return retval;
-    } else
-	return 0;
+    }
+    if (MODEFLAGS & HAVE_EXT_SET) {
+	va_start(params, what);
+	retval |= driverspecs->ext_set(what, params);
+	va_end(params);
+    }
+    return retval;
 }
 
-
-
 /* Parse a string for options.. str is \0-terminated source,
    commands is an array of char ptrs (last one is NULL) containing commands
    to parse for. (if first char is ! case sensitive),
@@ -2293,7 +2395,7 @@ static char *vga_conf_commands[] =
     "linear", "!C0", "!C1", "!C2", "!C3", "!C4", "!C5", "!C6", "!C7", "!C8", "!C9",
     "!c0", "!c1", "monotext", "colortext", "!m5",
     "leavedtr", "cleardtr", "setdtr", "leaverts", "clearrts",
-    "setrts", "grayscale", "horizsync", "vertrefresh",
+    "setrts", "grayscale", "horizsync", "vertrefresh", "modeline",
     NULL};
 
 static char *conf_mousenames[] =
@@ -2576,6 +2678,69 @@ static char *process_option(int command, int mode)
 		   "Example: VertRefresh 50 70\n");
 	}
 	break;
+    case 45:{			/* modeline */
+	    MonitorModeTiming mmt;
+	    const struct {
+		char *name;
+		int val;
+	    } options[] = {
+		{
+		    "-hsync", NHSYNC
+		},
+		{
+		    "+hsync", PHSYNC
+		},
+		{
+		    "-vsync", NVSYNC
+		},
+		{
+		    "+vsync", PVSYNC
+		},
+		{
+		    "interlace", INTERLACED
+		},
+		{
+		    "interlaced", INTERLACED
+		}
+	    };
+#define ML_NR_OPTS (sizeof(options)/sizeof(*options))
+
+	    /* Skip the name of the mode */
+	    ptr = strtok(NULL, " ");
+	    if (!ptr)
+		break;
+
+	    ptr = strtok(NULL, " ");
+	    if (!ptr)
+		break;
+	    mmt.pixelClock = atof(ptr) * 1000;
+
+#define ML_GETINT(x) \
+	ptr = strtok(NULL, " "); if(!ptr) break; \
+	mmt.##x = atoi(ptr);
+
+	    ML_GETINT(HDisplay);
+	    ML_GETINT(HSyncStart);
+	    ML_GETINT(HSyncEnd);
+	    ML_GETINT(HTotal);
+	    ML_GETINT(VDisplay);
+	    ML_GETINT(VSyncStart);
+	    ML_GETINT(VSyncEnd);
+	    ML_GETINT(VTotal);
+	    mmt.flags = 0;
+	    while ((ptr = strtok(NULL, " "))) {
+		for (i = 0; i < ML_NR_OPTS; i++)
+		    if (!strcasecmp(ptr, options[i].name))
+			mmt.flags |= options[i].val;
+		if (i == ML_NR_OPTS)
+		    break;
+	    }
+#undef ML_GETINT
+#undef ML_NR_OPTS
+
+	    addusertiming(&mmt);
+	    return ptr;
+	}
     }
   leave:
     return strtok(NULL, " ");
@@ -2685,11 +2850,15 @@ int iopl(int level)
     return 0;
 }
 
-unsigned long readb(unsigned long base, unsigned long off)
+unsigned long vga_readb(unsigned long base, unsigned long off)
 {
-    unsigned long result, shift, msb;
+    unsigned long result, shift;
+#if !defined(CONFIG_ALPHA_JENSEN)
+    unsigned long msb;
+#endif
 
     shift = (off & 0x3) * 8;
+#if !defined(CONFIG_ALPHA_JENSEN)
     if (off >= (1UL << 24)) {
 	msb = off & 0xf8000000;
 	off -= msb;
@@ -2697,16 +2866,21 @@ unsigned long readb(unsigned long base, unsigned long off)
 	    sethae(msb);
 	}
     }
-    result = *(vuip) ((off << 5) + base + 0x00);
+#endif
+    result = *(vuip) ((off << MEM_SHIFT) + base + MEM_TYPE_BYTE);
     result >>= shift;
     return 0xffUL & result;
 }
 
-unsigned long readw(unsigned long base, unsigned long off)
+unsigned long vga_readw(unsigned long base, unsigned long off)
 {
-    unsigned long result, shift, msb;
+    unsigned long result, shift;
+#if !defined(CONFIG_ALPHA_JENSEN)
+    unsigned long msb;
+#endif
 
     shift = (off & 0x3) * 8;
+#if !defined(CONFIG_ALPHA_JENSEN)
     if (off >= (1UL << 24)) {
 	msb = off & 0xf8000000;
 	off -= msb;
@@ -2714,13 +2888,24 @@ unsigned long readw(unsigned long base, unsigned long off)
 	    sethae(msb);
 	}
     }
-    result = *(vuip) ((off << 5) + base + 0x08);
+#endif
+    result = *(vuip) ((off << MEM_SHIFT) + base + MEM_TYPE_WORD);
     result >>= shift;
     return 0xffffUL & result;
 }
 
-void writeb(unsigned char b, unsigned long base, unsigned long off)
+#if defined(CONFIG_ALPHA_JENSEN)
+unsigned long vga_readl(unsigned long base, unsigned long off)
 {
+    unsigned long result;
+    result = *(vuip) ((off << MEM_SHIFT) + base + MEM_TYPE_LONG);
+    return 0xffffffffUL & result;
+}
+#endif
+
+void vga_writeb(unsigned char b, unsigned long base, unsigned long off)
+{
+#if !defined(CONFIG_ALPHA_JENSEN)
     unsigned long msb;
     unsigned int w;
 
@@ -2732,11 +2917,15 @@ void writeb(unsigned char b, unsigned long base, unsigned long off)
 	}
     }
   asm("insbl %2,%1,%0": "r="(w):"ri"(off & 0x3), "r"(b));
-    *(vuip) ((off << 5) + base + 0x00) = w;
+    *(vuip) ((off << MEM_SHIFT) + base + MEM_TYPE_BYTE) = w;
+#else
+    *(vuip) ((off << MEM_SHIFT) + base + MEM_TYPE_BYTE) = b * 0x01010101;
+#endif
 }
 
-void writew(unsigned short b, unsigned long base, unsigned long off)
+void vga_writew(unsigned short b, unsigned long base, unsigned long off)
 {
+#if !defined(CONFIG_ALPHA_JENSEN)
     unsigned long msb;
     unsigned int w;
 
@@ -2748,7 +2937,18 @@ void writew(unsigned short b, unsigned long base, unsigned long off)
 	}
     }
   asm("inswl %2,%1,%0": "r="(w):"ri"(off & 0x3), "r"(b));
-    *(vuip) ((off << 5) + base + 0x08) = w;
+    *(vuip) ((off << MEM_SHIFT) + base + MEM_TYPE_WORD) = w;
+#else
+    *(vuip) ((off << MEM_SHIFT) + base + MEM_TYPE_WORD) = b * 0x00010001;
+#endif
+}
+
+#if defined(CONFIG_ALPHA_JENSEN)
+void vga_writel(unsigned long b, unsigned long base, unsigned long off)
+{
+    *(vuip) ((off << MEM_SHIFT) + base + MEM_TYPE_LONG) = b;
 }
 
 #endif
+
+#endif
