@@ -46,12 +46,20 @@ int vga_clear(void)
 	    {
 		int i;
 		int pages = (CI.ydim * CI.xbytes + 65535) >> 16;
+#if defined(CONFIG_ALPHA_JENSEN)
+		int j;
+#endif
 
 		for (i = 0; i < pages; ++i) {
 		    vga_setpage(i);
 
+#if defined(CONFIG_ALPHA_JENSEN)
+		    for (j = 0; j < 65536; j += 2)
+			gr_writew(0, j);
+#else
 		    /* clear video memory */
 		    memset(GM, 0, 65536);
+#endif
 		}
 	    }
 	    break;
