@@ -99,37 +99,22 @@
 
 /* Prototypes of functions defined in vgaregs.c. */
 
-void __svgalib_setup_VGA_registers(
+void setup_VGA_registers(
 			    unsigned char *moderegs,
 			    ModeTiming * modetiming,
 			    ModeInfo * modeinfo
 );
 
-#if 0
 /* Write to indexed VGA register using outw. */
-void __svgalib_outGR(int index, unsigned char value);
-void __svgalib_outSR(int index, unsigned char value);
-void __svgalib_outCR(int index, unsigned char value);
+void outGR(int index, unsigned char value);
+void outSR(int index, unsigned char value);
+void outCR(int index, unsigned char value);
 
 /* Write to indexed VGA register using outb. */
-void __svgalib_outbGR(int index, unsigned char value);
-void __svgalib_outbSR(int index, unsigned char value);
-void __svgalib_outbCR(int index, unsigned char value);
+void outbGR(int index, unsigned char value);
+void outbSR(int index, unsigned char value);
+void outbCR(int index, unsigned char value);
 
-unsigned char __svgalib_inGR(int index);
-unsigned char __svgalib_inSR(int index);
-unsigned char __svgalib_inCR(int index);
-
-#else
-
-#define __svgalib_inGR __svgalib_ingra
-#define __svgalib_outGR __svgalib_outgra
-#define __svgalib_outbGR __svgalib_outgra
-#define __svgalib_inSR __svgalib_inseq
-#define __svgalib_outSR __svgalib_outseq
-#define __svgalib_outbSR __svgalib_outseq
-#define __svgalib_inCR __svgalib_incrtc
-#define __svgalib_outCR __svgalib_outcrtc
-#define __svgalib_outbCR __svgalib_outcrtc
-
-#endif
+unsigned char inGR(int index);
+unsigned char inSR(int index);
+unsigned char inCR(int index);
