@@ -1,9 +1,9 @@
 /*
 
-    3DKIT   version   1.3
+    3DKIT   version   1.2
     High speed 3D graphics and rendering library for Linux.
 
-    Copyright (C) 1996, 1997  Paul Sheer   psheer@icon.co.za
+    Copyright (C) 1996  Paul Sheer   psheer@hertz.mech.wits.ac.za
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -22,7 +22,6 @@
 
 */
 
-
 /*
 
 File: 3dinit.c
@@ -38,20 +37,17 @@ tools to initialise different 3D primitives.
 
 
 
-#include <config.h>
+
 #include <math.h>
 #include <stdlib.h>
 #include <stdio.h>
-
-#ifndef DO_NOT_USE_VGALIB
 #include <vga.h>
-#endif
-
 #include <vgagl.h>
 #include "./3dkit.h"
 #include "./3dinit.h"
 
 
+
 double mag (Vec v)
 {
     double r;
@@ -249,8 +245,8 @@ static inline void fxchg (double *a, double *b)
 }
 
 
-void TD_initellipsoidpart (TD_Surface * surf, int x, int y, int z,
-		      int a, int b, int c, int w, int dir, int col)
+void TD_initellipsoidpart (TD_Surface * surf, long x, long y, long z,
+		      long a, long b, long c, int w, int dir, int col)
 {
     int i, j;
     Vec v;
@@ -311,8 +307,8 @@ void TD_initellipsoidpart (TD_Surface * surf, int x, int y, int z,
 
 
 void TD_initellipsoid (TD_Surface * surf1, TD_Surface * surf2, TD_Surface * surf3,
-	TD_Surface * surf4, TD_Surface * surf5, TD_Surface * surf6, int x, 
-	int y, int z, int a, int b, int c, int w, int col)
+	TD_Surface * surf4, TD_Surface * surf5, TD_Surface * surf6, long x, 
+	long y, long z, long a, long b, long c, int w, int col)
 {
     TD_initellipsoidpart (surf1, x, y, z, a, b, c, w, 0, col);
     TD_initellipsoidpart (surf2, x, y, z, a, b, c, w, 1, col);
@@ -323,8 +319,8 @@ void TD_initellipsoid (TD_Surface * surf1, TD_Surface * surf2, TD_Surface * surf
 }
 
 
-void TD_initsellipsoid (TD_Solid *s, int n, int x, 
-	int y, int z, int a, int b, int c, int w, int col)
+void TD_initsellipsoid (TD_Solid *s, int n, long x, 
+	long y, long z, long a, long b, long c, int w, int col)
 {
     TD_initellipsoid(&s->surf[n], &s->surf[n+1], &s->surf[n+2], 
 	&s->surf[n+3], &s->surf[n+4], &s->surf[n+5], x, y, z,
